@@ -101,7 +101,7 @@ pipeline]""",
     is_flag=True,
     show_default=True,
 )
-@logging_parameters()
+@logging_parameters(DEFAULT_PUBLISHFLOW_LOGCONFIG)
 def publish_flow_main(
     default_branch: str,
     disable_pr_publish: typing.Optional[str],
