@@ -64,7 +64,9 @@ def _setup_context(this_dir: pathlib.Path) -> ProjectContext:
     venv_bin = temp_path / ".venv/bin"
 
     run_command(["python3", "-m", "venv", str(venv_dir)])
-    run_command([str(venv_bin / "pip"), "install", "."])
+    # trick the install to not download build-harness by pre-installing the
+    # local build-harness package
+    run_command([str(venv_bin / "pip"), "install", ".[dev,doc,test]"])
 
     this_context = ProjectContext(
         temp_path=temp_path,
