@@ -51,7 +51,8 @@ class TestRunTests:
         mock_result = mocker.MagicMock()
         mock_result.returncode = 0
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_tests(self.MOCK_OPTIONS, None, False)
@@ -60,7 +61,8 @@ class TestRunTests:
         mock_result = mocker.MagicMock()
         mock_result.returncode = 1
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         with pytest.raises(UnitTestError, match=r"^unit tests failed"):
@@ -75,7 +77,8 @@ TOTAL                                  170     44    91%
         mock_result.returncode = 0
         mock_result.stdout = mock_captured_report
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_tests(self.MOCK_OPTIONS, 90, False)
@@ -89,7 +92,8 @@ TOTAL                                  170     44    90%
         mock_result.returncode = 0
         mock_result.stdout = mock_captured_report
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_tests(self.MOCK_OPTIONS, 90, False)
@@ -103,7 +107,8 @@ TOTAL                                  170     44    89%
         mock_result.returncode = 0
         mock_result.stdout = mock_captured_report
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         with pytest.raises(TestCoverageError, match=r"^Coverage test failed"):
@@ -118,7 +123,8 @@ TOTAL                                  170     44    100%
         mock_result.returncode = 0
         mock_result.stdout = mock_captured_report
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_tests(self.MOCK_OPTIONS, 90, False)
@@ -132,7 +138,8 @@ TOTAL                                  170     44    0%
         mock_result.returncode = 0
         mock_result.stdout = mock_captured_report
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_tests(self.MOCK_OPTIONS, 0, False)
@@ -142,10 +149,13 @@ TOTAL                                  170     44    0%
         mock_result.returncode = 0
         mock_result.stdout = None
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
-        with pytest.raises(TestCoverageError, match=r"^no coverage report captured"):
+        with pytest.raises(
+            TestCoverageError, match=r"^no coverage report captured"
+        ):
             _run_tests(self.MOCK_OPTIONS, 0, False)
 
     def test_no_tests_raises(self, mocker):
@@ -156,7 +166,8 @@ TOTAL                                  170     44    0%
         mock_result = mocker.MagicMock()
         mock_result.returncode = 5
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         with pytest.raises(UnitTestError, match=r"^unit tests failed"):
@@ -170,7 +181,8 @@ TOTAL                                  170     44    0%
         mock_result = mocker.MagicMock()
         mock_result.returncode = 5
         mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
 
         _run_tests(mock_options, None, False)
@@ -295,7 +307,12 @@ class TestCoverageReports:
     def test_coverage_html_explicit(self, click_runner, mocker, mock_run):
         result = click_runner.invoke(
             main,
-            ["unit-test", "--coverage-html", "--coverage-html-file", "some/html/path"],
+            [
+                "unit-test",
+                "--coverage-html",
+                "--coverage-html-file",
+                "some/html/path",
+            ],
         )
 
         assert result.exit_code == 0
@@ -336,7 +353,12 @@ class TestCoverageReports:
     def test_coverage_xml_explicit(self, click_runner, mocker, mock_run):
         result = click_runner.invoke(
             main,
-            ["unit-test", "--coverage-xml", "--coverage-xml-file", "some/xml/file"],
+            [
+                "unit-test",
+                "--coverage-xml",
+                "--coverage-xml-file",
+                "some/xml/file",
+            ],
         )
 
         assert result.exit_code == 0
@@ -358,7 +380,12 @@ class TestCoverageReports:
     def test_multiple_coverage(self, click_runner, mocker, mock_run):
         result = click_runner.invoke(
             main,
-            ["unit-test", "--coverage-console", "--coverage-html", "--coverage-xml"],
+            [
+                "unit-test",
+                "--coverage-console",
+                "--coverage-html",
+                "--coverage-xml",
+            ],
         )
 
         assert result.exit_code == 0
@@ -433,7 +460,8 @@ class TestCoverageCheck:
         mock_result.returncode = 0
         mock_result.stdout = self.mock_captured_report
         mock_run = mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
         result = click_runner.invoke(main, ["unit-test", "--check", "91"])
 
@@ -458,7 +486,8 @@ class TestCoverageCheck:
         mock_result.returncode = 0
         mock_result.stdout = self.mock_captured_report
         mock_run = mocker.patch(
-            "build_harness.commands.unit_tests.run_command", return_value=mock_result
+            "build_harness.commands.unit_tests.run_command",
+            return_value=mock_result,
         )
         result = click_runner.invoke(main, ["unit-test", "--check", "92"])
 
